@@ -52,17 +52,18 @@ class Actor(object, Estudiante):
     """
 
     def __init__(self, imagen="sin_imagen.png", x=0, y=0):
-        if not pilas.motor:
+        if not pilas.mundo:
             mensaje = "Tiene que invocar a la funcion ``pilas.iniciar()`` para comenzar."
             print mensaje
             raise Exception(mensaje)
 
         Estudiante.__init__(self)
-        self._actor = pilas.motor.obtener_actor(imagen, x=x, y=y)
+        self._actor = pilas.mundo.motor.obtener_actor(imagen, x=x, y=y)
         self.centro = ('centro', 'centro')
 
         self.x = x
         self.y = y
+        self.transparencia = 0
 
         # Define el nivel de lejania respecto del observador.
         self.z = 0
@@ -70,6 +71,7 @@ class Actor(object, Estudiante):
         self.radio_de_colision = 10
         pilas.actores.utils.insertar_como_nuevo_actor(self)
         self._transparencia = 0
+        self.anexados = []
 
     def definir_centro(self, (x, y)):
         if type(x) == str:
@@ -81,7 +83,6 @@ class Actor(object, Estudiante):
                 raise Exception("No puedes definir '%s' como eje vertical." %(y))
             y = self._interpretar_y_convertir_posicion(y, self.obtener_alto())            
 
-        
         self._centro = (x, y)
         self._actor.definir_centro(x, y)
     
@@ -109,12 +110,6 @@ class Actor(object, Estudiante):
     def dibujar(self, aplicacion):
         self._actor.dibujar(aplicacion)
 
-    def obtener_area(self):
-        return self._actor.obtener_area()
-
-    
-    area = property(obtener_area)
-
     def get_x(self):
         x, y = self.obtener_posicion()
         return x
@@ -202,6 +197,7 @@ class Actor(object, Estudiante):
     def eliminar(self):
         "Elimina el actor de la lista de actores que se imprimen en pantalla."
         self.destruir()
+        self._eliminar_anexados()
     
     def destruir(self):
         "Elimina a un actor pero de manera inmediata."
@@ -214,7 +210,10 @@ class Actor(object, Estudiante):
         
         Este metodo se llama una vez por frame, y generalmente se redefine
         en alguna subclase."""
-        pass
+
+    def pre_actualizar(self):
+        self.actualizar_comportamientos()
+        self.actualizar_habilidades()
 
     def __cmp__(self, otro_actor):
         """Compara dos actores para determinar cual esta mas cerca de la camara.
@@ -278,6 +277,7 @@ class Actor(object, Estudiante):
         return self._actor.obtener_rotacion()
 
     def definir_rotacion(self, r):
+        r = r % 360
         self._actor.definir_rotacion(r)
 
     def definir_color(self, c):
@@ -288,6 +288,7 @@ class Actor(object, Estudiante):
 
     def definir_imagen(self, imagen):
         self._actor.definir_imagen(imagen)
+        self.centro = ('centro', 'centro')
 
     def duplicar(self, **kv):
         duplicado = self.__class__()
@@ -298,14 +299,22 @@ class Actor(object, Estudiante):
         return duplicado
 
     def obtener_ancho(self):
-        return self.obtener_area()[0]
+        return self.imagen.ancho()
 
     def obtener_alto(self):
-        return self.obtener_area()[1]
+        return self.imagen.alto()
 
     ancho = property(obtener_ancho)
     alto = property(obtener_alto)
 
+    def __mul__(self, cantidad):
+        if type(cantidad) is not int or cantidad < 1:
+            raise TypeError("Solo puede multiplicar por numeros enteros mayores a 1.")
+
+        grupo = pilas.atajos.fabricar(self.__class__, cantidad - 1)
+        grupo.append(self)
+        return grupo
+
     def __str__(self):
         return "<%s en (%d, %d)>" %(self.__class__.__name__, self.x, self.y)
 
@@ -319,4 +328,21 @@ class Actor(object, Estudiante):
         self._actor.definir_transparencia(valor)
 
     def imitar(self, otro_actor_o_figura):
-	self.aprender(pilas.habilidades.Imitar, otro_actor_o_figura)
+        self.aprender(pilas.habilidades.Imitar, otro_actor_o_figura)
+
+    def esta_fuera_de_la_pantalla(self):
+        # TODO: detectar area de la pantalla con las funciones que exporta el motor.
+        if self.derecha < -320 or self.izquierda > 320 or self.arriba < -240 or self.abajo > 240:
+                return True
+
+    def decir(self, mensaje, autoeliminar=True):
+        nuevo_actor = pilas.actores.Globo(mensaje, self.x, self.y, autoeliminar=autoeliminar)
+        nuevo_actor.z = self.z - 1
+        self.anexar(nuevo_actor)
+
+    def anexar(self, otro_actor):
+        self.anexados.append(otro_actor)
+
+    def _eliminar_anexados(self):
+        for x in self.anexados:
+            x.eliminar()
