@@ -13,8 +13,9 @@ class Opcion(Texto):
 
     def __init__(self, texto, x=0, y=0, funcion_a_invocar=None):
         Texto.__init__(self, texto, x=x, y=y)
+        self.magnitud = 20
         self.funcion_a_invocar = funcion_a_invocar
-        self.color = pilas.colores.negro
+        self.color = pilas.colores.gris
         self.z = -300
         self.centro = ("centro", "centro")
 
@@ -22,9 +23,9 @@ class Opcion(Texto):
         "Pinta la opcion actual de un color mas claro."
 
         if estado:
-            self.color = pilas.colores.blanco
-        else:
             self.color = pilas.colores.negro
+        else:
+            self.color = pilas.colores.gris
 
     def seleccionar(self):
         "Invoca a la funcion que tiene asociada para ejecutar."
