@@ -15,33 +15,46 @@ class Texto(Actor):
     El texto tiene atributos como ``texto``, ``magnitud`` y ``color``.
     """
     
-    def __init__(self, texto="None", x=0, y=0):
-        Actor.__init__(self, x=x, y=y)
-        self._actor = pilas.motor.obtener_texto(texto, x, y)
+    def __init__(self, texto="None", x=0, y=0, magnitud=20):
+        imagen = pilas.mundo.motor.obtener_texto(texto)
+        self._definir_area_de_texto(texto, magnitud)
+        Actor.__init__(self, imagen, x=x, y=y)
+        self.magnitud = magnitud
         self.texto = texto
-        self.x = x
-        self.y = y
+        self.color = pilas.colores.blanco
+        self.centro = ("centro", "centro")
 
     def obtener_texto(self):
-        return self._actor.obtener_texto()
+        return self.imagen.texto
 
     def definir_texto(self, texto):
-        self._actor.definir_texto(texto)
+        self.imagen.texto = texto
+        self._definir_area_de_texto(texto, self.magnitud)
 
     texto = property(obtener_texto, definir_texto, doc="El texto que se tiene que mostrar.")
     
     def obtener_magnitud(self):
-        return self._actor.obtener_magnitud()
+        return self.imagen.magnitud
     
     def definir_magnitud(self, magnitud):
-        self._actor.definir_magnitud(magnitud)
+        self._magnitud = magnitud
+        self.imagen.magnitud = magnitud
     
     magnitud = property(obtener_magnitud, definir_magnitud, doc="El tamaño del texto.")
     
     def obtener_color(self):
-        return self._actor.obtener_color()
+        return self.imagen.color
     
     def definir_color(self, color):
-        self._actor.definir_color(color)
+        self.imagen.color = color
 
-    color = property(obtener_color, definir_color, doc="Color del texto.")
\ No newline at end of file
+    color = property(obtener_color, definir_color, doc="Color del texto.")
+
+    def obtener_ancho(self):
+        return self._ancho
+
+    def obtener_alto(self):
+        return self._alto
+
+    def _definir_area_de_texto(self, texto, magnitud):
+        self._ancho, self._alto = pilas.mundo.motor.obtener_area_de_texto(texto, magnitud)
