@@ -12,7 +12,7 @@ class Fondo(pilas.actores.Actor):
 
     def __init__(self, imagen):
         pilas.actores.Actor.__init__(self, imagen)
-        self.z = 100
+        self.z = 1000
 
 class Volley(Fondo):
     "Muestra una escena que tiene un fondo de pantalla de paisaje."
@@ -52,18 +52,13 @@ class Noche(Fondo):
     def __init__(self):
         Fondo.__init__(self, "fondos/noche.png")
 
-class Blanco(Fondo):
-    "Un fondo de color blanco."
-
-    def __init__(self):
-        Fondo.__init__(self, "fondos/blanco.png")
-        
-        
 class Color(Fondo):
     
     def __init__(self, color):
-        self.lienzo = pilas.lienzo.Lienzo()
-        self.lienzo.pintar(color)
         Fondo.__init__(self, "invisible.png")
-        self.lienzo.asignar(self)
-        self.centro = ("centro", "centro")
+        self.color = color
+        self.lienzo = pilas.imagenes.cargar_lienzo()
+
+    def dibujar(self, motor):
+        if self.color:
+            self.lienzo.pintar(motor, self.color)
