@@ -1,6 +1,20 @@
+#import pygame
+import time
 import pygame
 
+class ___FPS:
+
+    def __init__(self, fps, usar_modo_economico):
+        pass
+
+    def actualizar(self):
+        time.sleep(1 / 40.0)
+
+    def obtener_cuadros_por_segundo(self):
+        return 0
+
 class FPS:
+    #print "Usando pygame en el modulo fps"
 
     def __init__(self, fps, usar_modo_economico):
         self.antes = self.ahora = pygame.time.get_ticks()
@@ -40,4 +54,4 @@ class FPS:
 
 
     def obtener_cuadros_por_segundo(self):
-        return self.cuadros_por_segundo
\ No newline at end of file
+        return self.cuadros_por_segundo
