@@ -6,7 +6,6 @@
 #
 # website - http://www.pilas-engine.com.ar
 
-import os
 import sys
 import copy
 from PyQt4 import QtGui, QtCore
@@ -16,8 +15,8 @@ try:
     from PyQt4 import QtOpenGL
     from PyQt4.QtOpenGL import QGLWidget
 except ImportError:
-    QGLWidget = object
-    print "No se encuentra soporte OpenGL en este equipo."
+    QGLWidget = None
+    print "No se encuentra OpenGL en este equipo."
 
 
 import motor
@@ -31,22 +30,16 @@ from pilas import fps
 from pilas import simbolos
 from pilas import colores
 
-# Allow close azulejo witch ctrl+c
-import signal                                                                                    
-signal.signal(signal.SIGINT, signal.SIG_DFL)
 
-
-class BaseActor(object):
+class BaseActor:
     
     def __init__(self):
         self._rotacion = 0
+        self._escala = 1
         self._transparencia = 0
         self.centro_x = 0
         self.centro_y = 0
-        self._escala_x = 1
-        self._escala_y = 1
         self._espejado = False
-        self.fijo = 0
 
     def definir_centro(self, x, y):
         self.centro_x = x
@@ -59,17 +52,10 @@ class BaseActor(object):
         self.x, self.y = x, y
 
     def obtener_escala(self):
-        return self._escala_x
+        return self._escala
 
     def definir_escala(self, s):
-        self._escala_x = s
-        self._escala_y = s
-
-    def definir_escala_x(self, s):
-        self._escala_x = s
-
-    def definir_escala_y(self, s):
-        self._escala_y = s
+        self._escala = s
 
     def definir_transparencia(self, nuevo_valor):
         self._transparencia = nuevo_valor
@@ -86,10 +72,9 @@ class BaseActor(object):
     def set_espejado(self, espejado):        
         self._espejado = espejado
         
-class Imagen(object):
+class QtImagen():
 
     def __init__(self, ruta):
-        self.ruta_original = ruta
         self._imagen = QtGui.QPixmap(ruta)
 
     def ancho(self):
@@ -129,12 +114,8 @@ class Imagen(object):
     def _dibujar_pixmap(self, motor, x, y):
         motor.canvas.drawPixmap(x, y, self._imagen)
 
-    def __str__(self):
-        nombre_imagen = os.path.basename(self.ruta_original)
-        return "<Imagen del archivo '%s'>" %(nombre_imagen)
 
-
-class Grilla(Imagen):
+class QtGrilla(QtImagen):
 
     """Representa una grilla regular, que se utiliza en animaciones.
 
@@ -145,12 +126,12 @@ class Grilla(Imagen):
     """
 
     def __init__(self, ruta, columnas=1, filas=1):
-        Imagen.__init__(self, ruta)
+        QtImagen.__init__(self, ruta)
         self.cantidad_de_cuadros = columnas * filas
         self.columnas = columnas
         self.filas = filas
-        self.cuadro_ancho = Imagen.ancho(self) / columnas
-        self.cuadro_alto = Imagen.alto(self) / filas
+        self.cuadro_ancho = QtImagen.ancho(self) / columnas
+        self.cuadro_alto = QtImagen.alto(self) / filas
         self.definir_cuadro(0)
 
     def ancho(self):
@@ -183,16 +164,10 @@ class Grilla(Imagen):
         self.definir_cuadro(cuadro_actual)
         return ha_reiniciado
 
-    def obtener_cuadro(self):
-        return self._cuadro
-
     def dibujarse_sobre_una_pizarra(self, pizarra, x, y):
         pizarra.pintar_parte_de_imagen(self, self.dx, self.dy, self.cuadro_ancho, self.cuadro_alto, x, y)
 
-class Texto(Imagen):
-
-    def __init__(self, texto, magnitud, motor):
-        self._ancho, self._alto = motor.obtener_area_de_texto(texto, magnitud)
+class QtTexto(QtImagen):
 
     def _dibujar_pixmap(self, motor, dx, dy):
         nombre_de_fuente = motor.canvas.font().family()
@@ -205,17 +180,11 @@ class Texto(Imagen):
         lines = self.texto.split('\n')
 
         for line in lines:
-            motor.canvas.drawText(dx, dy + self._alto, line)
+            motor.canvas.drawText(dx, dy, line)
             dy += metrica.height()
 
-    def ancho(self):
-        return self._ancho
 
-    def alto(self):
-        return self._alto
-
-
-class Lienzo(Imagen):
+class QtLienzo(QtImagen):
 
     def __init__(self):
         pass
@@ -286,7 +255,7 @@ class Lienzo(Imagen):
         motor.canvas.setPen(pen)
         motor.canvas.drawRect(x, y, ancho, alto)
 
-class Superficie(Imagen):
+class QtSuperficie(QtImagen):
 
     def __init__(self, ancho, alto):
         self._imagen = QtGui.QPixmap(ancho, alto)
@@ -381,7 +350,7 @@ class Superficie(Imagen):
     def limpiar(self):
         self._imagen.fill(QtGui.QColor(0, 0, 0, 0))
 
-class Actor(BaseActor):
+class QtActor(BaseActor):
 
     def __init__(self, imagen="sin_imagen.png", x=0, y=0):
 
@@ -396,7 +365,7 @@ class Actor(BaseActor):
 
     def definir_imagen(self, imagen):
         # permite que varios actores usen la misma grilla.
-        if isinstance(imagen, Grilla):
+        if isinstance(imagen, QtGrilla):
             self.imagen = copy.copy(imagen)
         else:
             self.imagen = imagen
@@ -405,28 +374,19 @@ class Actor(BaseActor):
         return self.imagen
 
     def dibujar(self, motor):
-        escala_x, escala_y = self._escala_x, self._escala_y
-
+        escala_x, escala_y = self._escala, self._escala
         if self._espejado:
             escala_x *= -1
 
-        if not self.fijo:
-            x = self.x - motor.camara_x
-            y = self.y - motor.camara_y
-        else:
-            x = self.x
-            y = self.y
-
-        self.imagen.dibujar(motor, x, y,
+        self.imagen.dibujar(motor, self.x, self.y, 
                 self.centro_x, self.centro_y,
                 escala_x, escala_y, self._rotacion, self._transparencia)
 
-class Sonido:
+class QtSonido:
 
     def __init__(self, ruta):
         import pygame
         pygame.mixer.init()
-        pygame.mixer.init()
         self.sonido = pygame.mixer.Sound(ruta)
 
     def reproducir(self):
@@ -434,8 +394,84 @@ class Sonido:
         # print "Usando pygame para reproducir sonido"
         self.sonido.play()
         
-class Base(motor.Motor):
+class SFMLCanvas:
+    "Representa una superficie sobre la que se puede dibujar usando cairo."
+    # TODO
+
+    def __init__(self, ancho, alto):
+        self.ancho = ancho
+        self.alto = alto
+        self.surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, ancho, alto)
+        self.image = sf.Image()
+        self.context = cairo.Context(self.surface)
+        self.actualizar()
+
+    def actualizar(self):
+        self.image.LoadFromPixels(self.ancho, self.alto, self.surface.get_data())
+
+    def limpiar(self):
+        self.surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, self.ancho, self.alto)
+        self.context = cairo.Context(self.surface)       
+
+               
+
+    def __init__(self, ancho, alto, titulo):
+        super(Ventana, self).__init__()
+        self.init()
+        self.sprites = []
+
+        '''
+        self.mouse = QtGui.QCursor()
+
+        time = QtCore.QTimer()
+        time.singleShot(50, self.hacer_flotante_la_ventana_en_i3)
+        '''
+
+    def do_update(self):
+        self.update()
+        '''
+        position = self.mapFromGlobal(QtGui.QCursor.pos())
+        x = position.x()
+        y = position.y()
+        self.sprites[0].x = x
+        self.sprites[0].y = y
+        '''
+
+    def hacer_flotante_la_ventana_en_i3(self):
+        try:
+            subprocess.call(['i3-msg', 't'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        except OSError:
+            pass
+
+    def paintEvent(self, event):
+        self.canvas.begin(self)
+        #self.qp.scale(self.scale_x, self.scale_y)
+        self.canvas.setClipRect(0, 0, 640, 480)
+
+        # Hace que el centro de coordenadas sea (0, 0)
+        # self.qp.setWindow(-320, -240, 640, 480)
+        # self.qp.setRenderHint(QtGui.QPainter.HighQualityAntialiasing, True)
+        self.render(event, self.canvas)
+        self.canvas.end()
+
+
+
+
+
+    def keyPressEvent(self, event):
+        print "Pulsa la tecla:", event.key()
+
+    def wheelEvent(self, event):
+        print "Mueve rueda:", event.delta()
+
+
+    def render(self, event, qp):
+        for r in self.sprites:
+            r.dibujar(self.canvas)
+        
+class QtBase(motor.Motor):
     
+    app = QtGui.QApplication([])
     
     def __init__(self):
         motor.Motor.__init__(self)
@@ -446,8 +482,6 @@ class Base(motor.Motor):
         self.depurador = depurador.Depurador(self.obtener_lienzo(), self.fps)
         self.mouse_x = 0
         self.mouse_y = 0
-        self.camara_x = 0
-        self.camara_y = 0
 
     def iniciar_ventana(self, ancho, alto, titulo, pantalla_completa):
         self.ancho = ancho
@@ -458,35 +492,13 @@ class Base(motor.Motor):
         self.centrar_ventana()
         self.setWindowTitle(self.titulo)
 
-        self.mostrar_ventana(pantalla_completa)
-
-        # Activa la invocacion al evento timerEvent.
-        self.startTimer(1000/60.0)
-
-    def mostrar_ventana(self, pantalla_completa):
         if pantalla_completa:
             self.showFullScreen()
         else:
             self.show()
 
-    def pantalla_completa(self):
-        self.showFullScreen()
-
-    def pantalla_modo_ventana(self):
-        self.showNormal()
-
-    def esta_en_pantalla_completa(self):
-        return self.isFullScreen()
-
-    def alternar_pantalla_completa(self):
-        """Permite cambiar el modo de video.
-
-        Si está en modo ventana, pasa a pantalla completa y viceversa.
-        """
-        if self.esta_en_pantalla_completa():
-            self.pantalla_modo_ventana()
-        else:
-            self.pantalla_completa()
+        # Activa la invocacion al evento timerEvent.
+        self.startTimer(1000/100.0)
 
     def centro_fisico(self):
         "Centro de la ventana para situar el punto (0, 0)"
@@ -502,35 +514,146 @@ class Base(motor.Motor):
                     (escritorio.height()-self.alto)/2, self.ancho, self.alto)
 
     def obtener_actor(self, imagen, x, y):
-        return Actor(imagen, x, y)
+        return QtActor(imagen, x, y)
 
-    def obtener_texto(self, texto, magnitud):
-        return Texto(texto, magnitud, self)
+    def obtener_texto(self, texto):
+        return QtTexto(texto)
 
+    def obtener_posicion_del_mouse(self):
+        #return (self.mouse_x, self.mouse_y)
+        pass
+    
+    def obtener_canvas(self, ancho, alto):
+        return SFMLCanvas(ancho, alto)
+    
     def obtener_grilla(self, ruta, columnas, filas):
-        return Grilla(ruta, columnas, filas)
+        return QtGrilla(ruta, columnas, filas)
+
+
+    def ocultar_puntero_del_mouse(self):
+        self.ventana.ShowMouseCursor(False)
+
+    def mostrar_puntero_del_mouse(self):
+        self.ventana.ShowMouseCursor(True)
+
+    def cerrar_ventana(self):
+        self.ventana.Close()
+
+
+
+    def procesar_y_emitir_eventos(self):
+        "Procesa todos los eventos que la biblioteca SFML pone en una cola."
+        return
+        '''
+        pass
+        event = self.event
+
+        while self.ventana.GetEvent(self.event):
+            if event.Type == sf.Event.Closed:
+                pilas.mundo.terminar()
+            if event.Type == sf.Event.KeyPressed:
+                self.procesar_evento_teclado(event)
+
+                if event.Key.Code == sf.Key.Q and event.Key.Alt:
+                    pilas.mundo.terminar()
+            elif event.Type == sf.Event.TextEntered:
+
+                eventos.pulsa_tecla.send("ejecutar", codigo=unichr(event.Text.Unicode)) 
+            elif event.Type == sf.Event.MouseMoved:
+                # Notifica el movimiento del mouse con una señal
+
+                x, y = event.MouseMove.X, event.MouseMove.Y
+
+                if x > 0 and y > 0:
+                    x, y = self.ventana.ConvertCoords(x, y)
+                    y = -y
+
+                    # Se asegura de los eventos de mouse esten siempre
+                    # dentro de la ventana.
+                    x = min(320, x)
+                    y = max(y, -240)
+
+                    dx = x - self.mouse_x
+                    dy = y - self.mouse_y
+
+                    self.mouse_x = x
+                    self.mouse_y = y
+
+                    eventos.mueve_mouse.send("ejecutar", x=x, y=y, dx=dx, dy=dy)
+
+            elif event.Type == sf.Event.MouseButtonPressed:
+                x, y = self.ventana.ConvertCoords(event.MouseButton.X, event.MouseButton.Y)
+                eventos.click_de_mouse.send("ejecutar", button=event.MouseButton.Button, x=x, y=-y)
+            elif event.Type == sf.Event.MouseButtonReleased:
+                x, y = self.ventana.ConvertCoords(event.MouseButton.X, event.MouseButton.Y)
+                eventos.termina_click.send("ejecutar", button=event.MouseButton.Button, x=x, y=-y)
+            elif event.Type == sf.Event.MouseWheelMoved:
+                eventos.mueve_rueda.send("ejecutar", delta=event.MouseWheel.Delta)
+        '''
+
+    def procesar_evento_teclado(self, event):
+        code = event.Key.Code
+        
+        if code == sf.Key.P and event.Key.Alt:
+            pilas.mundo.alternar_pausa()
+        elif code == sf.Key.F4:
+            pilas.motor.guardar_captura()
+        elif code == sf.Key.F6:
+            pilas.utils.listar_actores_en_consola()                
+        elif code == sf.Key.F7:
+            eventos.imprimir_todos()
+        elif code in [sf.Key.F8, sf.Key.F9, sf.Key.F10, sf.Key.F11, sf.Key.F12]:
+            pilas.mundo.depurador.pulsa_tecla(code)
+        elif code == sf.Key.Escape:
+            eventos.pulsa_tecla_escape.send("ejecutar")
 
     def actualizar_pantalla(self):
         self.ventana.update()
 
     def definir_centro_de_la_camara(self, x, y):
-        self.camara_x = x
-        self.camara_y = y
+        view = self.ventana.GetDefaultView()
+        view.SetCenter(x, y)
 
     def obtener_centro_de_la_camara(self):
-        return (self.camara_x, self.camara_y)
+        view = self.ventana.GetDefaultView()
+        return view.GetCenter()
 
+    def pintar(self, color):
+        pass
+            
     def cargar_sonido(self, ruta):
-        return Sonido(ruta)
+        return QtSonido(ruta)
 
     def cargar_imagen(self, ruta):
-        return Imagen(ruta)
+        return QtImagen(ruta)
 
     def obtener_lienzo(self):
-        return Lienzo()
+        return QtLienzo()
 
     def obtener_superficie(self, ancho, alto):
-        return Superficie(ancho, alto)
+        return QtSuperficie(ancho, alto)
+
+    def guardar_captura(self):
+        imagen = self.ventana.Capture()
+        numero = self._obtener_numeracion_siguiente_imagen()
+        nombre = "imagen_%d.png" %(numero)
+        imagen.SaveToFile(nombre)
+        print "Guardando el archivo %s" %(nombre)
+
+    def _obtener_numeracion_siguiente_imagen(self):
+        "Obtiene un numero de imagen para guardar una captura."
+        lista_de_archivos = glob.glob("imagen_*.png")
+
+        if lista_de_archivos:
+            archivos = "\n".join(lista_de_archivos)
+            patron = "_(.+).png"
+            numeros = [int(x) for x in re.findall(patron, archivos)]
+            numeros.sort()
+            ultimo_numero = numeros[-1] + 1
+        else:
+            ultimo_numero = 1
+
+        return ultimo_numero
 
     def ejecutar_bucle_principal(self, mundo, ignorar_errores):
         sys.exit(self.app.exec_())
@@ -538,13 +661,9 @@ class Base(motor.Motor):
     def paintEvent(self, event):
         self.canvas.begin(self)
 
-        self.canvas.setClipping(True)
-        self.canvas.setClipRect(0, 0, self.alto * self.ancho_original / self.alto_original, self.alto)
-
         alto = self.alto / float(self.alto_original)
         self.canvas.scale(alto, alto)
 
-
         self.canvas.setRenderHint(QtGui.QPainter.HighQualityAntialiasing, False)
         self.canvas.setRenderHint(QtGui.QPainter.SmoothPixmapTransform, True)
         self.canvas.setRenderHint(QtGui.QPainter.Antialiasing, False)
@@ -567,11 +686,19 @@ class Base(motor.Motor):
         try:
             self.realizar_actualizacion_logica()
         except Exception as e:
-            print e.__class__.__name__ + ": " + str(e)
+            print e
 
         # Invoca el dibujado de la pantalla.
         self.update()
 
+        '''
+        self.procesar_y_emitir_eventos()
+                
+        if not self.mundo.pausa_habilitada:
+            self.mundo._realizar_actualizacion_logica(self.ignorar_errores)
+
+        self.mundo.realizar_actualizacion_grafica()
+        '''
 
     def realizar_actualizacion_logica(self):
         for x in range(self.fps.actualizar()):
@@ -581,9 +708,6 @@ class Base(motor.Motor):
                 for actor in actores.todos:
                     actor.pre_actualizar()
                     actor.actualizar()
-            else:
-                eventos.actualizar_pausado.send("Qt::timerEvent")
-
 
     def resizeEvent(self, event):
         self.ancho = event.size().width()
@@ -599,9 +723,6 @@ class Base(motor.Motor):
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
         eventos.termina_click.send("Qt::mouseReleaseEvent", x=x, y=y, dx=0, dy=0)
 
-    def wheelEvent(self, e):
-        eventos.mueve_rueda.send("ejecutar", delta=e.delta() / 120)
-
     def mouseMoveEvent(self, e):
         escala = self.escala()
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
@@ -615,10 +736,6 @@ class Base(motor.Motor):
 
         if event.key() == QtCore.Qt.Key_Escape:
             eventos.pulsa_tecla_escape.send("Qt::keyPressEvent")
-        if event.key() == QtCore.Qt.Key_P and event.modifiers() == QtCore.Qt.AltModifier:
-            self.alternar_pausa()
-        if event.key() == QtCore.Qt.Key_F and event.modifiers() == QtCore.Qt.AltModifier:
-            self.alternar_pantalla_completa()
 
         eventos.pulsa_tecla.send("Qt::keyPressEvent", codigo=codigo_de_tecla, texto=event.text())
 
@@ -634,44 +751,11 @@ class Base(motor.Motor):
             QtCore.Qt.Key_Down: simbolos.ABAJO,
             QtCore.Qt.Key_Space: simbolos.SELECCION,
             QtCore.Qt.Key_Return: simbolos.SELECCION,
-            QtCore.Qt.Key_F1: simbolos.F1,
-            QtCore.Qt.Key_F2: simbolos.F2,
-            QtCore.Qt.Key_F3: simbolos.F3,
-            QtCore.Qt.Key_F4: simbolos.F4,
-            QtCore.Qt.Key_F5: simbolos.F5,
-            QtCore.Qt.Key_F6: simbolos.F6,
-            QtCore.Qt.Key_F7: simbolos.F7,
             QtCore.Qt.Key_F8: simbolos.F8,
             QtCore.Qt.Key_F9: simbolos.F9,
             QtCore.Qt.Key_F10: simbolos.F10,
             QtCore.Qt.Key_F11: simbolos.F11,
             QtCore.Qt.Key_F12: simbolos.F12,
-            QtCore.Qt.Key_A: simbolos.a,
-            QtCore.Qt.Key_B: simbolos.b,
-            QtCore.Qt.Key_C: simbolos.c,
-            QtCore.Qt.Key_D: simbolos.d,
-            QtCore.Qt.Key_E: simbolos.e,
-            QtCore.Qt.Key_F: simbolos.f,
-            QtCore.Qt.Key_G: simbolos.g,
-            QtCore.Qt.Key_H: simbolos.h,
-            QtCore.Qt.Key_I: simbolos.i,
-            QtCore.Qt.Key_J: simbolos.j,
-            QtCore.Qt.Key_K: simbolos.k,
-            QtCore.Qt.Key_L: simbolos.l,
-            QtCore.Qt.Key_M: simbolos.m,
-            QtCore.Qt.Key_N: simbolos.n,
-            QtCore.Qt.Key_O: simbolos.o,
-            QtCore.Qt.Key_P: simbolos.p,
-            QtCore.Qt.Key_Q: simbolos.q,
-            QtCore.Qt.Key_R: simbolos.r,
-            QtCore.Qt.Key_S: simbolos.s,
-            QtCore.Qt.Key_T: simbolos.t,
-            QtCore.Qt.Key_U: simbolos.u,
-            QtCore.Qt.Key_V: simbolos.v,
-            QtCore.Qt.Key_W: simbolos.w,
-            QtCore.Qt.Key_X: simbolos.x,
-            QtCore.Qt.Key_Y: simbolos.y,
-            QtCore.Qt.Key_Z: simbolos.z,
         }
 
         if teclas.has_key(tecla_qt):
@@ -699,82 +783,17 @@ class Base(motor.Motor):
 
         return ancho, alto
 
-    def alternar_pausa(self):
-        if self.pausa_habilitada:
-            self.pausa_habilitada = False
-            self.actor_pausa.eliminar()
-        else:
-            self.pausa_habilitada = True
-            self.actor_pausa = actores.Pausa()
-
-    def ocultar_puntero_del_mouse(self):
-        bitmap = QtGui.QBitmap(1, 1)
-        nuevo_cursor = QtGui.QCursor(bitmap, bitmap)
-        self.setCursor(QtGui.QCursor(nuevo_cursor))
-
-    def terminar(self):
-        self.Close()
-
-class Widget(Base, QWidget):
-
-    def __init__(self, app):
-        self.app = app
-        QWidget.__init__(self)
-        Base.__init__(self)
-
-class WidgetSugar(Widget):
+class Qt(QtBase, QWidget):
 
     def __init__(self):
-        Widget.__init__(self, None)
+        QWidget.__init__(self)
+        QtBase.__init__(self)
 
-    def ejecutar_bucle_principal(self, mundo, ignorar_errores):
-        pass
-
-    def mostrar_ventana(self, pantalla_completa):
-        pass
-
-class WidgetGL(Base, QGLWidget):
-
-    def __init__(self, app):
-        self.app = app
+class QtGL(QtBase, QGLWidget):
 
+    def __init__(self):
         if not QGLWidget:
             print "Lo siento, OpenGL no esta disponible..."
 
         QGLWidget.__init__(self)
-        Base.__init__(self)
-        self._pintar_fondo_negro()
-
-    def _pintar_fondo_negro(self):
-        color = QtGui.QColor(99, 0, 0)
-        self.setStyleSheet("QWidget { background-color: %s }" % color.name())
-
-
-class Motor(object):
-    """Representa la ventana principal de pilas.
-    
-    Esta clase construirá el objeto apuntado por el atributo
-    ``pilas.motor``, asi que será el representante de todas
-    las funcionalidades multimedia.
-    
-    Internamente, este motor, tratará de usar OpenGl para acelerar
-    el dibujado en pantalla si la tarjeta de video lo soporta.
-    """
-
-    def __init__(self, usar_motor):
-        if usar_motor == 'qtgl':
-            app = QtGui.QApplication([])
-
-            if QGLWidget == object:
-                self.widget = Widget(app)
-            else:
-                self.widget = WidgetGL(app)
-        elif usar_motor == 'qt':
-            app = QtGui.QApplication([])
-            self.widget = Widget(app)
-        elif usar_motor == 'qtsugar':
-            self.widget = WidgetSugar()
-
-    def __getattr__(self, method):
-        "Delega todos los pedidos de funcionalidad al widget interno."
-        return getattr(self.widget, method)
+        QtBase.__init__(self)
